<?php 
if (! defined('ABSPATH') ) exit;

if (! function_exists('TRS_BX_SLIDER_POST')){
	class TRS_BX_SLIDER_POST extends TRS_BX_SLIDER{
		
		private static $db_slider_key;
		private static $db_slider_meta_key;
		
		function __construct ()
		{
			parent::__construct();
			
			self::$db_slider_key = parent::getPluginSlug() . 'slider_details';
			self::$db_slider_meta_key = parent::getPluginSlug() . 'slider_meta';
			
			add_action('init', [$this, 'bx_slider_post_type']);
			add_action('add_meta_boxes_' . parent::getPluginSlug(), [$this, 'slider_meta_box']);
 			add_action ( 'admin_enqueue_scripts', [$this, 'add_media_button']);
			add_action( 'save_post_' . parent::getPluginSlug(), [$this, 'save_slider_post'], 10, 2);
			add_action( 'wp_ajax_get_slider_item_template', [$this, 'get_slider_item_template'] );
			
		}
		
		/**
		 * @return string
		 */
		public static function getDbSliderKey ()
		{
			return self::$db_slider_key;
		}
		
		
		
		// Register Custom Post Type
		public function bx_slider_post_type() {
			
			$labels = array(
				'name'                  => _x( 'BX Sliders', 'Post Type General Name', 'therightsol' ),
				'singular_name'         => _x( 'BX Slider', 'Post Type Singular Name', 'therightsol' ),
				'menu_name'             => __( 'BX Slider', 'therightsol' ),
				'name_admin_bar'        => __( 'BX Slider', 'therightsol' ),
				'archives'              => __( 'Item Archives', 'therightsol' ),
				'attributes'            => __( 'Item Attributes', 'therightsol' ),
				'parent_item_colon'     => __( 'Parent Slider:', 'therightsol' ),
				'all_items'             => __( 'All Sliders', 'therightsol' ),
				'add_new_item'          => __( 'Add New Slider', 'therightsol' ),
				'add_new'               => __( 'Add New Slider', 'therightsol' ),
				'new_item'              => __( 'New Slider', 'therightsol' ),
				'edit_item'             => __( 'Edit Slider', 'therightsol' ),
				'update_item'           => __( 'Update Slider', 'therightsol' ),
				'view_item'             => __( 'View Slider', 'therightsol' ),
				'view_items'            => __( 'View Sliders', 'therightsol' ),
				'search_items'          => __( 'Search Slider', 'therightsol' ),
				'not_found'             => __( 'Not found', 'therightsol' ),
				'not_found_in_trash'    => __( 'Not found in Trash', 'therightsol' ),
				'featured_image'        => __( 'Featured Image', 'therightsol' ),
				'set_featured_image'    => __( 'Set featured image', 'therightsol' ),
				'remove_featured_image' => __( 'Remove featured image', 'therightsol' ),
				'use_featured_image'    => __( 'Use as featured image', 'therightsol' ),
				'insert_into_item'      => __( 'Insert into item', 'therightsol' ),
				'uploaded_to_this_item' => __( 'Uploaded to this item', 'therightsol' ),
				'items_list'            => __( 'Items list', 'therightsol' ),
				'items_list_navigation' => __( 'Items list navigation', 'therightsol' ),
				'filter_items_list'     => __( 'Filter items list', 'therightsol' ),
			);
			$args = array(
				'label'                 => __( 'BX Slider', 'therightsol' ),
				'description'           => __( 'Create BX Slider', 'therightsol' ),
				'labels'                => $labels,
				'supports'              => array( 'title', ),
				'hierarchical'          => false,
				'public'                => false,
				'show_ui'               => true,
				'show_in_menu'          => true,
				'menu_position'         => 5,
				'menu_icon'             => 'dashicons-format-gallery',
				'show_in_admin_bar'     => true,
				'show_in_nav_menus'     => true,
				'can_export'            => true,
				'has_archive'           => false,
				'exclude_from_search'   => false,
				'publicly_queryable'    => true,
				'capability_type'       => 'page',
			);
			register_post_type( parent::getPluginSlug(), $args );
		}
		
		
		public function slider_meta_box( ){
			add_meta_box(
				'bx-slider-slides-meta-box',
				__( 'Add Slides' ),
				[$this, 'render_slider_slides_meta_box'],
				parent::getPluginSlug(),
				'normal',
				'default'
			);
			
			add_meta_box(
				'bx-slider-shortcode-box',
				__( 'Slider Shortcode' ),
				[$this, 'render_slider_shortcode_meta_box'],
				parent::getPluginSlug(),
				'side',
				'default'
			);
			
			add_meta_box(
				'bx-slider-add-more-meta-box',
				__( 'Add More Slides' ),
				[$this, 'render_slider_add_more_meta_box'],
				parent::getPluginSlug(),
				'side',
				'default'
			);
			
			add_meta_box(
				'bx-slider-options-meta-box',
				__( 'Slider Options' ),
				[$this, 'render_slider_options_meta_box'],
				parent::getPluginSlug(),
				'side',
				'default'
			);
			
		}
		
		public function render_slider_options_meta_box ($post)
		{
		    $slider_meta = get_post_meta($post->ID, self::getDbSliderMetaKey(), true);
			$slider_height = (isset($slider_meta['slider_height']) && !empty($slider_meta['slider_height'])) ? $slider_meta['slider_height'] : '';
			$adaptive_height = (isset($slider_meta['adaptive_height']) && !empty($slider_meta['adaptive_height'])) ? $slider_meta['adaptive_height'] : '';
           	
            ob_start();
            ?>

            <div class="trs_meta_box">
                <div class="slider_height_wrapper">
                    <label for="slider_height"><?php _e('Slider Height', parent::getPluginTextDomain()); ?></label>
                    <input type="number" min="200" max="1600" step="1" name="slider_meta[slider_height]" class="slider_height" id="slider_height" value="<?php echo $slider_height; ?>">
                    <?php _e('px', parent::getPluginTextDomain()); ?>
                    <p class="description"><?php _e('Leave blank for auto height.'); ?></p>
                </div>

                <hr />
                
                <div class="slider_adaptive_height_wrapper">
                    <label for="adaptive_height"><?php _e('Adaptive Height', parent::getPluginTextDomain()); ?></label>
                    <input type="checkbox" <?php echo checked('true', $adaptive_height) ?> name="slider_meta[adaptive_height]" class="adaptive_height" id="adaptive_height" value="true">
					<?php _e('Enable', parent::getPluginTextDomain()); ?>
                    <p class="description"><?php _e('Check to enable adaptive height. If adaptive height is checked then Slider height will not work.'); ?></p>
                </div>

                <hr />
            </div>
            
            <?php
			$html = ob_get_clean();
			echo apply_filters('render_slider_options_meta_box', $html);
		}
		
		public function render_slider_shortcode_meta_box ($post)
		{
			ob_start();
			?>
            <div class="slider_shortcode_metabox_wrapper">
                <?php echo ( new TRS_BX_SLIDER_COLUMNS( ) )->get_shortcode( $post->ID ); ?>
                <p class="description"><?php _e('You can copy / paste this short code into any page or page to display this slider.'); ?></p>
            </div>
			<?php
			$html = ob_get_clean();
			echo apply_filters('render_slider_shortcode_meta_box', $html);
		}
		
		public function render_slider_add_more_meta_box ( )
		{
		    ob_start();
		    ?>
            <div class="add_more_wrapper">
                <a href="#." id="add_more" class="primary-btn button add_more"><?php _e('Add More', parent::getPluginTextDomain()) ?></a>
                <span class="spinner is-active hide addmore_spinner"></span>
            </div>
			
			<?php
            $html = ob_get_clean();
			echo apply_filters('render_slider_add_more_meta_box', $html);
 		}
		
		public function add_media_button(){
			if (is_admin ())
				wp_enqueue_media ();
		}
		
		public function render_slider_slides_meta_box( $post ){
			
			$slider_imgs = (!empty(get_post_meta($post->ID, self::$db_slider_key, true))) ? get_post_meta($post->ID, self::$db_slider_key, true) : [];
			$id = (! empty($slider_imgs)) ? ( sizeof($slider_imgs) + 1 ) : 0;
			
			ob_start();
			
			echo '<div class="item-parent">';
			
			foreach ($slider_imgs as $index => $imgArr){
				$template = $this->get_slider_item_template($index, $imgArr);
				echo $template;
			}
			?>
            <div class="wrap post_slider_imgs_wrapper">
				<?php if (intval($id) === 0) :
					echo $this->get_slider_item_template($id, []);
                endif; ?>
                <input type="hidden" value="<?php echo $id; ?>" id="i" name="i">
            </div>
			<?php
            
            echo '</div>';
            
			$html = ob_get_clean();
			
			echo apply_filters('render_slider_slides_meta_box', $html);
		}
		
		// This function return Template and this function called from aJax and from this Class.
		// So, you can see required if statements.
		public function get_slider_item_template ( $id = false, array $imgArr = [])
		{
			if (parent::is_ajax()){
				$img_id = '';
				$img_url = BACKEND_ASSET_URL . '/images/placeholder.jpg';
				$img_caption = '';
				
				$get_data = filter_input_array(INPUT_GET);
				$id = intval(sanitize_text_field($get_data['index']));
				include ( BACKEND_INCLUDES_DIR . '/template-slider-item.php' );
				
				wp_die();
			}
			
			
			$img_id = ( isset($imgArr['image_id']) && !empty($imgArr['image_id']) ) ? $imgArr['image_id'] : '';
			$img_url = (isset($imgArr['img_url']) && ! empty($imgArr['img_url'])) ? $imgArr['img_url'] : BACKEND_ASSET_URL . '/images/placeholder.jpg';
			$img_caption = (isset($imgArr['img_caption']) && !empty($imgArr['img_caption'])) ? $imgArr['img_caption'] : '';
			
			
			
			include ( BACKEND_INCLUDES_DIR . '/template-slider-item.php' );
		}
		
		/**
		 * @return string
		 */
		public static function getDbSliderMetaKey ()
		{
			return self::$db_slider_meta_key;
		}
		
		
		
		public function save_slider_post ( $post_id, $post )
		{
			if (wp_is_post_revision( $post_id ))
				return;
			
			if (wp_is_post_autosave( $post_id ))
				return;
			
			if ( ! current_user_can( 'manage_options' ) )
				return;
			
			if (get_post_type( $post_id ) !== parent::getPluginSlug())
				return;
			
			$posted_data = filter_input_array(INPUT_POST);
			
			if ( isset($posted_data[parent::getPluginSlug()]) ){
				update_post_meta( $post_id, self::$db_slider_key, $posted_data[parent::getPluginSlug()] );
			}
			
			if (!isset($posted_data['slider_meta']['adaptive_height']))
				$posted_data['slider_meta']['adaptive_height'] = false;
			//$this->debug($posted_data, true);
			
			if (isset($posted_data['slider_meta'])){
			    update_post_meta( $post_id, self::$db_slider_meta_key, $posted_data['slider_meta']);
            }
			
			return;
		}
		
	}
	new TRS_BX_SLIDER_POST();
}

